@@ -281,6 +281,7 @@ void display_network_outages(void) {
 	int total_entries = 0;
 
 	/* user must be authorized for all hosts.. */
+/*
 	if(is_authorized_for_all_hosts(&current_authdata) == FALSE) {
 
 		printf("<P><DIV CLASS='errorMessage'>It appears as though you do not have permission to view information you requested...</DIV></P>\n");
@@ -289,6 +290,7 @@ void display_network_outages(void) {
 
 		return;
 		}
+*/
 
 	/* find all hosts that are causing network outages */
 	find_hosts_causing_outages();
@@ -432,6 +434,9 @@ void find_hosts_causing_outages(void) {
 			if(temp_host == NULL)
 				continue;
 
+			if (!is_authorized_for_host(temp_host, &current_authdata))
+				continue;
+
 			/* if the route to this host is not blocked, it is a causing an outage */
 			if(is_route_to_host_blocked(temp_host) == FALSE)
 				add_hostoutage(temp_host);
