@@ -860,9 +860,9 @@ void display_map(void) {
 	if(create_type == CREATE_HTML) {
 		printf("<P><DIV ALIGN=center>\n");
 #ifdef LEGACY_GRAPHICAL_CGIS
-		printf("<img src='%s?host=%s&createimage&time=%lu", STATUSMAP_CGI, url_encode(host_name), (unsigned long)time(NULL));
+		printf("<img src='%s?host=%s&createimage&time=%llu", STATUSMAP_CGI, url_encode(host_name), (unsigned long long)time(NULL));
 #else
-		printf("<img src='%s?host=%s&createimage&time=%lu", LEGACY_STATUSMAP_CGI, url_encode(host_name), (unsigned long)time(NULL));
+		printf("<img src='%s?host=%s&createimage&time=%llu", LEGACY_STATUSMAP_CGI, url_encode(host_name), (unsigned long long)time(NULL));
 #endif
 		printf("&canvas_x=%d&canvas_y=%d&canvas_width=%d&canvas_height=%d&max_width=%d&max_height=%d&layout=%d%s%s%s", canvas_x, canvas_y, canvas_width, canvas_height, max_image_width, max_image_height, layout_method, (use_links == FALSE) ? "&nolinks" : "", (use_text == FALSE) ? "&notext" : "", (use_highlights == FALSE) ? "&nohighlights" : "");
 		print_layer_url(TRUE);
