@@ -2,8 +2,6 @@
  *
  * BROKER.H - Event broker includes for Nagios
  *
- * Copyright (c) 2002-2006 Ethan Galstad (egalstad@nagios.org)
- * Last Modified:   12-12-2006
  *
  * License:
  *
@@ -22,16 +20,11 @@
  *
  *****************************************************************************/
 
-#ifndef _BROKER_H
-#define _BROKER_H
+#ifndef NAGIOS_BROKER_H_INCLUDED
+#define NAGIOS_BROKER_H_INCLUDED
 
-#include "config.h"
 #include "nagios.h"
 
-#ifdef __cplusplus
-  extern "C" {
-#endif
-
 /*************** EVENT BROKER OPTIONS *****************/
 
 #define BROKER_NOTHING                  0
@@ -48,12 +41,12 @@
 #define BROKER_COMMENT_DATA         	256	/* DONE */
 #define BROKER_DOWNTIME_DATA		512     /* DONE */
 #define BROKER_SYSTEM_COMMANDS          1024	/* DONE */
-#define BROKER_OCP_DATA                 2048	/* DONE */
+#define BROKER_OCP_DATA_UNUSED          2048	/* reusable */
 #define BROKER_STATUS_DATA              4096    /* DONE */
 #define BROKER_ADAPTIVE_DATA            8192    /* DONE */
 #define BROKER_EXTERNALCOMMAND_DATA     16384   /* DONE */
 #define BROKER_RETENTION_DATA           32768   /* DONE */
-#define BROKER_ACKNOWLEDGEMENT_DATA     65536  
+#define BROKER_ACKNOWLEDGEMENT_DATA     65536
 #define BROKER_STATECHANGE_DATA         131072
 #define BROKER_RESERVED18               262144
 #define BROKER_RESERVED19               524288
@@ -184,39 +177,37 @@
 /****** EVENT BROKER FUNCTIONS *************/
 
 #ifdef USE_EVENT_BROKER
+NAGIOS_BEGIN_DECL
+
 struct timeval get_broker_timestamp(struct timeval *);
-void broker_program_state(int,int,int,struct timeval *);
-void broker_timed_event(int,int,int,timed_event *,struct timeval *);
-void broker_log_data(int,int,int,char *,unsigned long,time_t,struct timeval *);
-int broker_event_handler(int,int,int,int,void *,int,int,struct timeval,struct timeval,double,int,int,int,char *,char *,char *,struct timeval *);
-void broker_ocp_data(int,int,int,void *,int,int,double,int,int,struct timeval *);
-void broker_system_command(int,int,int,struct timeval,struct timeval,double,int,int,int,char *,char *,struct timeval *);
-int broker_host_check(int,int,int,host *,int,int,int,struct timeval,struct timeval,char *,double,double,int,int,int,char *,char *,char *,char *,struct timeval *);
-int broker_service_check(int,int,int,service *,int,struct timeval,struct timeval,char *,double,double,int,int,int,char *,struct timeval *);
-void broker_comment_data(int,int,int,int,int,char *,char *,time_t,char *,char *,int,int,int,time_t,unsigned long,struct timeval *);
-void broker_downtime_data(int,int,int,int,char *,char *,time_t,char *,char *,time_t,time_t,int,unsigned long,unsigned long,unsigned long,struct timeval *);
-void broker_flapping_data(int,int,int,int,void *,double,double,double,struct timeval *);
-void broker_program_status(int,int,int,struct timeval *);
-void broker_host_status(int,int,int,host *,struct timeval *);
-void broker_service_status(int,int,int,service *,struct timeval *);
-void broker_contact_status(int,int,int,contact *,struct timeval *);
-void broker_notification_data(int,int,int,int,int,struct timeval,struct timeval,void *,char *,char *,int,int,struct timeval *);
-void broker_contact_notification_data(int,int,int,int,int,struct timeval,struct timeval,void *,contact *,char *,char *,int,struct timeval *);
-void broker_contact_notification_method_data(int,int,int,int,int,struct timeval,struct timeval,void *,contact *,char *,char *,char *,int,struct timeval *);
-void broker_adaptive_program_data(int,int,int,int,unsigned long,unsigned long,unsigned long,unsigned long,struct timeval *);
-void broker_adaptive_host_data(int,int,int,host *,int,unsigned long,unsigned long,struct timeval *);
-void broker_adaptive_service_data(int,int,int,service *,int,unsigned long,unsigned long,struct timeval *);
-void broker_adaptive_contact_data(int,int,int,contact *,int,unsigned long,unsigned long,unsigned long,unsigned long,unsigned long,unsigned long, struct timeval *);
-void broker_external_command(int,int,int,int,time_t,char *,char *,struct timeval *);
-void broker_aggregated_status_data(int,int,int,struct timeval *);
-void broker_retention_data(int,int,int,struct timeval *);
-void broker_acknowledgement_data(int,int,int,int,void *,char *,char *,int,int,int,struct timeval *);
-void broker_statechange_data(int,int,int,int,void *,int,int,int,int,struct timeval *);
-#endif
+void broker_program_state(int, int, int, struct timeval *);
+void broker_timed_event(int, int, int, timed_event *, struct timeval *);
+void broker_log_data(int, int, int, char *, unsigned long, time_t, struct timeval *);
+int broker_event_handler(int, int, int, int, void *, int, int, struct timeval, struct timeval, double, int, int, int, char *, char *, char *, struct timeval *);
+void broker_system_command(int, int, int, struct timeval, struct timeval, double, int, int, int, char *, char *, struct timeval *);
+int broker_host_check(int, int, int, host *, int, int, int, struct timeval, struct timeval, char *, double, double, int, int, int, char *, char *, char *, char *, struct timeval *, check_result *);
+int broker_service_check(int, int, int, service *, int, struct timeval, struct timeval, char *, double, double, int, int, int, char *, struct timeval *, check_result *);
+void broker_comment_data(int, int, int, int, int, char *, char *, time_t, char *, char *, int, int, int, time_t, unsigned long, struct timeval *);
+void broker_downtime_data(int, int, int, int, char *, char *, time_t, char *, char *, time_t, time_t, int, unsigned long, unsigned long, unsigned long, struct timeval *);
+void broker_flapping_data(int, int, int, int, void *, double, double, double, struct timeval *);
+void broker_program_status(int, int, int, struct timeval *);
+void broker_host_status(int, int, int, host *, struct timeval *);
+void broker_service_status(int, int, int, service *, struct timeval *);
+void broker_contact_status(int, int, int, contact *, struct timeval *);
+int broker_notification_data(int, int, int, int, int, struct timeval, struct timeval, void *, char *, char *, int, int, struct timeval *);
+int broker_contact_notification_data(int, int, int, int, int, struct timeval, struct timeval, void *, contact *, char *, char *, int, struct timeval *);
+int broker_contact_notification_method_data(int, int, int, int, int, struct timeval, struct timeval, void *, contact *, char *, char *, char *, int, struct timeval *);
+void broker_adaptive_program_data(int, int, int, int, unsigned long, unsigned long, unsigned long, unsigned long, struct timeval *);
+void broker_adaptive_host_data(int, int, int, host *, int, unsigned long, unsigned long, struct timeval *);
+void broker_adaptive_service_data(int, int, int, service *, int, unsigned long, unsigned long, struct timeval *);
+void broker_adaptive_contact_data(int, int, int, contact *, int, unsigned long, unsigned long, unsigned long, unsigned long, unsigned long, unsigned long, struct timeval *);
+void broker_external_command(int, int, int, int, time_t, char *, char *, struct timeval *);
+void broker_aggregated_status_data(int, int, int, struct timeval *);
+void broker_retention_data(int, int, int, struct timeval *);
+void broker_acknowledgement_data(int, int, int, int, void *, char *, char *, int, int, int, struct timeval *);
+void broker_statechange_data(int, int, int, int, void *, int, int, int, int, struct timeval *);
 
-
-#ifdef __cplusplus
-  }
+NAGIOS_END_DECL
 #endif
 
 #endif
