@@ -18,8 +18,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  ************************************************************************/
 
-#ifndef _CGIUTILS_H
-#define _CGIUTILS_H
+#ifndef NAGIOS_CGIUTILS_H_INCLUDED
+#define NAGIOS_CGIUTILS_H_INCLUDED
 #include "lib/libnagios.h"
 #include "logging.h"
 #include "objects.h"
@@ -38,7 +38,7 @@ NAGIOS_BEGIN_DECL
 #ifdef LEGACY_GRAPHICAL_CGIS
 #define STATUSMAP_CGI		"statusmap.cgi"
 #else
-#define STATUSMAP_CGI		"../map.html"
+#define STATUSMAP_CGI		"../map.php"
 #define LEGACY_STATUSMAP_CGI		"statusmap.cgi"
 #endif
 #define STATUSWORLD_CGI	        "statuswrl.cgi"
