@@ -2,7 +2,6 @@
  *
  * Nagios Common Header File
  * Written By: Ethan Galstad (egalstad@nagios.org)
- * Last Modified: 10-22-2007
  *
  * License:
  *
@@ -20,32 +19,82 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  ************************************************************************/
 
+#ifndef NAGIOS_COMMON_H_INCLUDED
+#define NAGIOS_COMMON_H_INCLUDED
 
-#define PROGRAM_VERSION "3.2.3"
-#define PROGRAM_MODIFICATION_DATE "10-03-2010"
+#include "shared.h"
 
-/*#define DEBUG_CHECK_IPC 1 */
-/*#define DEBUG_CHECK_IPC2 1*/
+#define PROGRAM_VERSION "4.2.1"
+#define PROGRAM_MODIFICATION_DATE "09-06-2016"
 
+NAGIOS_BEGIN_DECL
 
+/*************************************************************/
+/************** SHARED GLOBAL VARIABLES **********************/
+/*************************************************************/
+extern int date_format;
+extern int interval_length;
+extern char *illegal_output_chars;
+extern char illegal_output_char_map[256];
 
-/* daemon is thread safe */
-#ifdef NSCORE
-#ifndef _REENTRANT
-#define _REENTRANT
-#endif
-#ifndef _THREAD_SAFE
-#define _THREAD_SAFE
+extern int log_rotation_method;
+extern int check_external_commands;
+/* set this if you're going to add a ton of comments at once */
+extern int defer_comment_sorting;
+extern unsigned long next_downtime_id;
+
+extern char *object_cache_file;
+extern char *status_file;
+
+extern time_t program_start;
+extern int nagios_pid;
+extern int daemon_mode;
+
+extern time_t last_log_rotation;
+
+extern int process_performance_data;
+extern int enable_flap_detection;
+extern int enable_notifications;
+extern int execute_service_checks;
+extern int accept_passive_service_checks;
+extern int execute_host_checks;
+extern int accept_passive_host_checks;
+extern int enable_event_handlers;
+extern int obsess_over_services;
+extern int obsess_over_hosts;
+
+extern int enable_timing_point;
+
+extern char *config_file_dir;
+
+#ifdef HAVE_TZNAME
+#ifdef CYGWIN
+extern char     *_tzname[2] __declspec(dllimport);
+#else
+extern char     *tzname[2];
 #endif
 #endif
 
+
+NAGIOS_END_DECL
+
+
 /* Experimental performance tweaks - use with caution */
 #undef USE_MEMORY_PERFORMANCE_TWEAKS
 
-/* my_free has been freed from bondage as a function */
-#define my_free(ptr) { if(ptr) { free(ptr); ptr = NULL; } }
-
 
+/****************** OBJECT STATES ********************/
+#define STATE_OK			0
+#define STATE_WARNING			1
+#define STATE_CRITICAL			2
+#define STATE_UNKNOWN			3
+#define STATE_UP                0
+#define STATE_DOWN              1
+#define STATE_UNREACHABLE       2
+/* for legacy reasons */
+#define HOST_UP              STATE_UP
+#define HOST_DOWN            STATE_DOWN
+#define HOST_UNREACHABLE     STATE_UNREACHABLE
 
 /***************************** COMMANDS *********************************/
 
@@ -150,26 +199,20 @@
 #define CMD_ENABLE_HOSTGROUP_SVC_CHECKS                 67
 #define CMD_DISABLE_HOSTGROUP_SVC_CHECKS                68
 
-#define CMD_CANCEL_HOST_DOWNTIME                        69 /* not internally implemented */
-#define CMD_CANCEL_SVC_DOWNTIME                         70 /* not internally implemented */
-
-#define CMD_CANCEL_ACTIVE_HOST_DOWNTIME                 71 /* old - no longer used */
-#define CMD_CANCEL_PENDING_HOST_DOWNTIME                72 /* old - no longer used */
-
-#define CMD_CANCEL_ACTIVE_SVC_DOWNTIME                  73 /* old - no longer used */
-#define CMD_CANCEL_PENDING_SVC_DOWNTIME                 74 /* old - no longer used */
-
-#define CMD_CANCEL_ACTIVE_HOST_SVC_DOWNTIME             75 /* unimplemented */
-#define CMD_CANCEL_PENDING_HOST_SVC_DOWNTIME            76 /* unimplemented */
-
-#define CMD_FLUSH_PENDING_COMMANDS                      77
+/* commands 69-77 are unimplemented */
+#define CMD_UNIMPLEMENTED_69                            69
+#define CMD_UNIMPLEMENTED_70                            70
+#define CMD_UNIMPLEMENTED_71                            71
+#define CMD_UNIMPLEMENTED_72                            72
+#define CMD_UNIMPLEMENTED_73                            73
+#define CMD_UNIMPLEMENTED_74                            74
+#define CMD_UNIMPLEMENTED_75                            75
+#define CMD_UNIMPLEMENTED_76                            76
+#define CMD_UNIMPLEMENTED_77                            77
 
 #define CMD_DEL_HOST_DOWNTIME                           78
 #define CMD_DEL_SVC_DOWNTIME                            79
 
-#define CMD_ENABLE_FAILURE_PREDICTION                   80
-#define CMD_DISABLE_FAILURE_PREDICTION                  81
-
 #define CMD_ENABLE_PERFORMANCE_DATA                     82
 #define CMD_DISABLE_PERFORMANCE_DATA                    83
 
@@ -264,7 +307,7 @@
 #define CMD_SET_SVC_NOTIFICATION_NUMBER                 143
 
 /* new commands in Nagios 3.x found below... */
-#define CMD_CHANGE_HOST_CHECK_TIMEPERIOD                144  
+#define CMD_CHANGE_HOST_CHECK_TIMEPERIOD                144
 #define CMD_CHANGE_SVC_CHECK_TIMEPERIOD                 145
 
 #define CMD_PROCESS_FILE                                146
@@ -299,26 +342,42 @@
 #define CMD_CHANGE_CONTACT_MODHATTR                     168
 #define CMD_CHANGE_CONTACT_MODSATTR                     169
 
+#define CMD_DEL_DOWNTIME_BY_HOST_NAME                   170
+#define CMD_DEL_DOWNTIME_BY_HOSTGROUP_NAME              171
+#define CMD_DEL_DOWNTIME_BY_START_TIME_COMMENT          172
+
 /* custom command introduced in Nagios 3.x */
 #define CMD_CUSTOM_COMMAND                              999
 
+/**************************** COMMAND ERRORS *****************************/
+#define CMD_ERROR_OK 0 /* No errors encountered */
+#define CMD_ERROR_UNKNOWN_COMMAND 1 /* Unknown/unsupported command */
+#define CMD_ERROR_MALFORMED_COMMAND 2 /* Command malformed/missing timestamp? */
+#define CMD_ERROR_INTERNAL_ERROR 3 /* Internal error */
+#define CMD_ERROR_FAILURE 4 /* Command routine failed */
+
+extern const char *cmd_error_strerror(int error_code);
+
+/**************************** CHECK TYPES ********************************/
+
+#define CHECK_TYPE_ACTIVE   0
+#define CHECK_TYPE_PASSIVE  1
+#define CHECK_TYPE_PARENT   2 /* (active) check for the benefit of dependent objects */
+#define CHECK_TYPE_FILE     3 /* from spool files (yuck) */
+#define CHECK_TYPE_OTHER    4 /* for modules to use */
 
 
-/************************ SERVICE CHECK TYPES ****************************/
+/************* LEGACY (deprecated) CHECK TYPES ***************************/
 
-#define SERVICE_CHECK_ACTIVE		0	/* Nagios performed the service check */
-#define SERVICE_CHECK_PASSIVE		1	/* the service check result was submitted by an external source */
-
-
-/************************** HOST CHECK TYPES *****************************/
-
-#define HOST_CHECK_ACTIVE		0	/* Nagios performed the host check */
-#define HOST_CHECK_PASSIVE		1	/* the host check result was submitted by an external source */
+#define SERVICE_CHECK_ACTIVE    CHECK_TYPE_ACTIVE
+#define SERVICE_CHECK_PASSIVE   CHECK_TYPE_PASSIVE
+#define HOST_CHECK_ACTIVE       CHECK_TYPE_ACTIVE
+#define HOST_CHECK_PASSIVE      CHECK_TYPE_PASSIVE
 
 
 /************************ SERVICE STATE TYPES ****************************/
 
-#define SOFT_STATE			0	
+#define SOFT_STATE			0
 #define HARD_STATE			1
 
 
@@ -360,11 +419,12 @@
 #define CHECK_OPTION_FORCE_EXECUTION	1	/* force execution of a check (ignores disabled services/hosts, invalid timeperiods) */
 #define CHECK_OPTION_FRESHNESS_CHECK    2       /* this is a freshness check */
 #define CHECK_OPTION_ORPHAN_CHECK       4       /* this is an orphan check */
+#define CHECK_OPTION_DEPENDENCY_CHECK   8       /* dependency check. different scheduling rules apply */
 
 
 /**************************** PROGRAM MODES ******************************/
 
-#define STANDBY_MODE		0	
+#define STANDBY_MODE		0
 #define ACTIVE_MODE		1
 
 
@@ -400,24 +460,6 @@
 #define MAX_CHECK_STATS_TYPES                11
 
 
-/************************* GENERAL DEFINITIONS  **************************/
-
-#define	OK				0
-#define ERROR				-2	/* value was changed from -1 so as to not interfere with STATUS_UNKNOWN plugin result */
-
-
-#ifndef TRUE
-#define TRUE				1
-#elif (TRUE!=1)
-#define TRUE				1
-#endif
-#ifndef FALSE
-#define FALSE				0
-#elif (FALSE!=0)
-#define FALSE				0
-#endif
-
-
 /****************** HOST CONFIG FILE READING OPTIONS ********************/
 
 #define READ_HOSTS			1
@@ -439,16 +481,6 @@
 #define READ_ALL_OBJECT_DATA            READ_HOSTS | READ_HOSTGROUPS | READ_CONTACTS | READ_CONTACTGROUPS | READ_SERVICES | READ_COMMANDS | READ_TIMEPERIODS | READ_SERVICEESCALATIONS | READ_SERVICEDEPENDENCIES | READ_HOSTDEPENDENCIES | READ_HOSTESCALATIONS | READ_HOSTEXTINFO | READ_SERVICEEXTINFO | READ_SERVICEGROUPS
 
 
-/************************** DATE RANGE TYPES ****************************/
-
-#define DATERANGE_CALENDAR_DATE  0  /* 2008-12-25 */
-#define DATERANGE_MONTH_DATE     1  /* july 4 (specific month) */
-#define DATERANGE_MONTH_DAY      2  /* day 21 (generic month) */
-#define DATERANGE_MONTH_WEEK_DAY 3  /* 3rd thursday (specific month) */
-#define DATERANGE_WEEK_DAY       4  /* 3rd thursday (generic month) */
-#define DATERANGE_TYPES          5 
-
-
 /************************** DATE/TIME TYPES *****************************/
 
 #define LONG_DATE_TIME			0
@@ -496,5 +528,4 @@
 #define MODATTR_CHECK_TIMEPERIOD                16384
 #define MODATTR_CUSTOM_VARIABLE                 32768
 #define MODATTR_NOTIFICATION_TIMEPERIOD         65536
-
-	
+#endif /* NAGIOS_COMMON_H_INCLUDED */
